==> nextcloud-29.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/eu.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "TOTP bi faktoreko autentifikazioa aktibatu duzu zure kontuan",
    "You disabled TOTP two-factor authentication for your account" : "TOTP bi faktoreko autentifikazioa desgaitu duzu zure kontuan",
    "TOTP two-factor authentication disabled by an admin" : "TOTP bi faktoreko autentifikazioa kudeatzaileak desaktibatu egin du",
    "TOTP (Authenticator app)" : "TOTP (autentifikazio app-a)",
    "Authenticate with a TOTP app" : "TOTP app-arekin izena eman",
    "Two-Factor TOTP Provider" : "TOTP bi faktoreko zerbitzua",
    "TOTP two-factor provider" : "TOTP bi faktoreko zerbitzua",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "TOTP eskaintzeko zerbitzua (RFC 6238)",
    "Enable TOTP" : "Gaitu TOTP",
    "Could not enable TOTP" : "Ezin izan da TOTP aktibatu",
    "Could not verify your key. Please try again" : "Ezin da zure gakoa ziurtatu. Saia zaitez berriz mesedez",
    "Your new TOTP secret is:" : "Zure TOTP sekretua hauxe da:",
    "For quick setup, scan this QR code with your TOTP app:" : "Konfigurazio azkarra lortzeko, eskaneatu QR kode hau zure TOTP aplikazioarekin:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Aplikazioa konfiguratu ondoren, idatzi beheko proba-kodea denak ondo funtzionatzen duela ziurtatzeko:",
    "Authentication code" : "Autentifikazio kodea",
    "Verify" : "Egiaztatu",
    "Get the authentication code from the two-factor authentication app on your device." : "Zure gailuko bi faktoreko autentifikazio aplikaziotik autentifikazio kodea lortu.",
    "Submit" : "Bidali"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.14.tgz: nextcloud/apps/twofactor_totp/l10n/eu.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "TOTP bi faktoreko autentifikazioa aktibatu duzu zure kontuan",
    "You disabled TOTP two-factor authentication for your account" : "TOTP bi faktoreko autentifikazioa desgaitu duzu zure kontuan",
    "TOTP (Authenticator app)" : "TOTP (autentifikazio app-a)",
    "Authenticate with a TOTP app" : "TOTP app-arekin izena eman",
    "Two-Factor TOTP Provider" : "TOTP bi faktoreko zerbitzua",
    "Could not enable TOTP" : "Ezin izan da TOTP aktibatu",
    "Could not verify your key. Please try again" : "Ezin da zure gakoa ziurtatu. Saia zaitez berriz mesedez",
    "Enable TOTP" : "Gaitu TOTP",
    "Your new TOTP secret is:" : "Zure TOTP sekretua hauxe da:",
    "For quick setup, scan this QR code with your TOTP app:" : "Konfigurazio azkarra lortzeko, eskaneatu QR kode hau zure TOTP aplikazioarekin:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Aplikazioa konfiguratu ondoren, idatzi beheko proba-kodea denak ondo funtzionatzen duela ziurtatzeko:",
    "Authentication code" : "Autentifikazio kodea",
    "Verify" : "Egiaztatu",
    "Get the authentication code from the two-factor authentication app on your device." : "Zure gailuko bi faktoreko autentifikazio aplikaziotik autentifikazio kodea lortu.",
    "Submit" : "Bidali",
    "TOTP two-factor authentication disabled by an admin" : "TOTP bi faktoreko autentifikazioa kudeatzaileak desaktibatu egin du",
    "TOTP two-factor provider" : "TOTP bi faktoreko zerbitzua",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "TOTP eskaintzeko zerbitzua (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
